#Results and Discussion


##Overall taxonomic diversity of ISS surfaces and comparison to previous high-throughput 16SrRNA study

After filtering chimeric and eukaryotic sequences from the data, the number of sequences per surface sampled ranged from 26,221 - 76,656. Open-reference clustering at 97% similarity resulted in 12,554 OTUs (OTU is a proxy for microbial "species".) This exceeds the number of species observed by Venkateswaran _et al._ 2014, which is not surprising, given the increased sampling depth in this study (~1 million versus ~ 50,000 high-quality sequences.) Our study also had three notable, qualitative differences from Venkateswaran _et al._ 2014. First, in their study, more than 90% of all sequences were assigned to 4 bacterial genera (_Corynebacterium_, _Propionibacterium_, _Staphylococcus_, and _Streptococcus_), while in the study here, they comprised only 24% of the data (9.6%, 0.05%, 10.7%, and 3.6%, respectively). Second, Venkateswaran _et al._ found no evidence of archaea in their samples, even when interrogating with archaeal-specific primers, but we did find evidence for a very low-abundance archaeal presence (2335 sequences, from three archaeal phyla). Finally, despite the fact that Venkateswaran at al. were able to culture many spore-forming organisms from their samples, they observed no sequence data from putative spore-forming organisms. However, a large percentage of sequences in our study are from spore-forming genera: 20.9% _Bacillus_ and 9.6% _Clostridium_. These differences are potentially due to differences in PCR primers and/or DNA extraction method, both of which have known taxonomic biases \cite{Brooks_2015}.

The 19 most abundant orders found in our study represent 93.8% of the data (Figure 1). Within each of these 19 orders, the most abundant genus found in our samples tends to be human-associated (Table 2). This is not surprising, as the only source of microbial influx is via occasional crew and cargo deliveries aboard spacecraft that have been stringently cleaned to avoid microbial contamination.

There were no apparent biogeographical patterns on the ISS surfaces. That is, there were no significant differences between samples obtained from the different modules (crew vs lab) or different surface types (keyboards, vents, or handheld mics). This can be visualized in Figure 2, in which each point represents one of the 15 samples, and the distance between samples indicates the overall difference in community composition. In Panel A, the metric used to calculate the distance between samples is the Bray-Curtis dissimilarity, and in Panel B, an alternative distance metric (Unifrac) is used, which takes into account the phylogenetic distance between the OTUs in samples. For the most part, all 15 samples form a tight cluster on the NMDS plots, but there is one sample, the starboard crew vent, that appears distinct from all of the other samples in Panel A. In Panel B, that same sample, as well as the aft lab vent sample appear separate from the others. In order to visualize which OTUs are contributing the most to the uniqueness of those samples, we looked at the overall distribution of the most abundant bacterial families in those samples. The three most abundant families in the starboard crew vent sample are Bacteroidaceae, Ruminococcaceae, and Verrumicrobiaceae (comprising 60.1% of all sequences); and the three most abundant families in the aft lab vent sample are Rikenellaceae, Bacteroidales S24-7, and Lactobacillaceae (comprising 60% of all sequences). In Figure 3, the relative abundance of these six families in all 15 samples from the ISS provides a clear indication that they are driving the distinctiveness of those two samples. 

##Comparison to the microbial communities of homes on Earth and from the Human Microbiome Project

To put the microbial communities that we found on ISS surfaces in the context of homes on Earth, we compared them to the communities found by citizen scientists when they swabbed nine surfaces throughout 40 homes, as part of the "Wildlife of Our Homes" project. We found that the ISS homes and Earth homes were significantly different from each other, both based on the Bray-Curtis dissimilarity (adonis, R^2=0.0666, P=0.001) and the Unifrac distance (adonis, R^2=0.04189, P=0.001). These differences can be visualized in the ordination plots in Figure 4 A and B. 

It is perhaps not surprising that the insular environment of the ISS would not resemble Earth homes. Unlike the ISS, homes on Earth are exposed to a variety of sources of microbes, including the outside air, tracked-in soil, plants, pets, and human inhabitants \cite{Barber_a_2015} \cite{Barber_b_2015}. The dominant source of microbes on the ISS is presumably the human microbiome. All spacecraft and cargo undergo rigorous decontamination procedures before launch to rendevous with the ISS. Therfore, we hypothesized that the microbial communities of the ISS surfaces might be more similar to human-associated microbial communities than Earth home surfaces. To test this hypothesis, we obtained 16S rDNA sequence data for 100 random samples from each of 13 body sites from the HMP Data Portal (http://hmpdacc.org/HM16STR/)\cite{Huttenhower_2012}\cite{Gevers_2012}. The microbial communities associated with the ISS, Earth homes, and the HMP samples were significantly different from each other (R^2 = 0.08, P < 0.001). (Also see Figure 5 A-D) However, the ISS communities are significantly more similar to the Earth home samples than the HMP samples (Student's t-test, p< 0.00001). This combined analysis also indicates that the starboard crew vent sample, which appears quite distinct from the rest of the ISS samples in Figure 2 A, is more similar to the human gastrointestinal HMP samples, which is corroborated by the dominance of animal gut-related OTUs found in that sample (see Figure 3, and Table 2.)

Finally, because the ISS is designed only to house six crew members, for a stay of six months each, only 220 individuals have visited the ISS since the year 2000. We hypothesized that there might be a relatively low microbial diversity on the ISS, either due to having a few total number of species, or due to the dominance of a very few species. In Figure 6, we note that Shannon diversity (which takes into account both the number of species present, and how evenly our sequences are distributed throughout those species) is relatively high on the ISS.

##Comparison to rooms with mechanical ventilation or open windows.

Kembel et al., 2012 \cite{Kembel_2012}, showed that rooms in a health-care facility that were primarily ventilated via an open window had greater phylogenetic diversity and lower proportion of OTUs closely related to known human pathogens than rooms that were mechanically ventilated. The only window on the ISS is never opened, and the doors are opened only briefly, every few months. Therefore, we hypothesized that for the samples from the ISS, the phylogenetic diversity would be lower and the proportion of OTUs closely related to known human pathogens would be higher than that seen for mechanically ventilated rooms. To test this hypothesis, we obtained the list of known human pathogens compiled by Kembel _et al._, 2012, and followed their procedure to identify the proportion of OTUs in the ISS samples that were closely related to them (see Methods for details). Surprisingly, but reassuringly, we found that the ISS samples are similar in both phylogenetic diversity and the proportion of OTUs closely related to known human pathogens as compared to the mechanically ventilated rooms in the health-care facility (Figure 7). 